#!/bin/bash
#
# TENSORFLOW_FQ_DIR is defined by the fake setup in build_tensorflow.sh

cd ${TENSORFLOW_FQ_DIR}
echo
echo "working in ${PWD}"
echo

# get the headers
cd ${TENSORFLOW_FQ_DIR}/tensorflow-*
tdir=${PWD}
echo "now working in tdir ${tdir}"
echo
makedir=${tdir}/tensorflow/contrib/makefile
gendir=${tdir}/tensorflow/contrib/makefile/gen/host_obj
dwndir=${tdir}/tensorflow/contrib/makefile/downloads
incdir=${TENSORFLOW_FQ_DIR}/include
mkdir -p ${incdir} || exit 1

# move the libraries
mkdir -p ${TENSORFLOW_FQ_DIR}/lib || exit 1
cp -p ${makedir}/gen/lib/libtensorflow-core.* ${TENSORFLOW_FQ_DIR}/lib || exit 1

# tensorflow headers
cd ${tdir}
# install set_ops.cc and set_kernels.cc as these two are required by semantic segmentation
# one might need to do #include "tensorflow/core/ops/set_ops.cc" (similarly for set_kernels.cc) 
# in their source file
header_list=`find tensorflow -type f -name "*.h" -o  -name set_ops.cc -o -name set_kernels.cc | grep -v makefile`
# we only need nysnc from contrib/makefile/downloads
download_list=`find tensorflow/contrib/makefile/downloads/nsync/public -type f -name "*.h"`
for my_header in ${header_list} ${download_list}
do
  my_header_dir=$(dirname "${my_header}")
  mkdir -p ${incdir}/${my_header_dir}
  cp -p ${my_header} ${incdir}/${my_header_dir}
done
# generated headers
cd ${gendir}
header_list=`find tensorflow -type f -name "*.h"`
for my_header in ${header_list}
do
  my_header_dir=$(dirname "${my_header}")
  mkdir -p ${incdir}/${my_header_dir}
  cp -p ${my_header} ${incdir}/${my_header_dir}
done
# third party headers
cd ${tdir}
header_list=`find third_party -type f -name "*.h" | grep -v contrib`
for my_header in ${header_list}
do
  my_header_dir=$(dirname "${my_header}")
  mkdir -p ${incdir}/${my_header_dir}
  cp -p ${my_header} ${incdir}/${my_header_dir}
done
# third party eigen headers
header_list=`find third_party/eigen3 -type f | grep -v contrib`
for my_header in ${header_list}
do
  my_header_dir=$(dirname "${my_header}")
  mkdir -p ${incdir}/${my_header_dir}
  cp -p ${my_header} ${incdir}/${my_header_dir}
done
# downloaded headers
cd ${dwndir}
header_list=`find absl  cub  double_conversion  fft2d  gemmlowp googletest re2 -type f -name "*.h"`
for my_header in ${header_list}
do
  my_header_dir=$(dirname "${my_header}")
  mkdir -p ${incdir}/${my_header_dir}
  cp -p ${my_header} ${incdir}/${my_header_dir}
done
# downloaded eigen headers
header_list=`find eigen/Eigen_tf eigen/unsupported -type f`
for my_header in ${header_list}
do
  my_header_dir=$(dirname "${my_header}")
  mkdir -p ${incdir}/${my_header_dir}
  cp -p ${my_header} ${incdir}/${my_header_dir}
done
# eigen signature file
cp -p eigen/signature_of_eigen3_matrix_library ${incdir}/eigen/ || exit 1

echo "install_all.sh completed successfully"
echo
exit 0
